@@ -24,18 +24,19 @@ import java.io.File;
 import org.codehaus.plexus.util.Os;
 import org.codehaus.plexus.util.StringUtils;
 
-import junit.framework.TestCase;
+import org.junit.Test;
+
+import static org.junit.Assert.*;
 
 /**
  * Test the PathDescriptor creation under various circumstances.
  *
  * @author <a href="mailto:henning@apache.org">Henning P. Schmiedehausen</a>
- * @version $Id: PathDescriptorTest.java 1058863 2011-01-14 06:43:36Z ltheussl $
  */
 public class PathDescriptorTest
-    extends TestCase
 {
     /** @throws Exception */
+    @Test
     public void testAbsPath()
         throws Exception
     {
@@ -54,6 +55,7 @@ public class PathDescriptorTest
     }
 
     /** @throws Exception */
+    @Test
     public void testRelPath()
         throws Exception
     {
@@ -72,6 +74,7 @@ public class PathDescriptorTest
     }
 
     /** @throws Exception */
+    @Test
     public void testEmptyAbsPath()
         throws Exception
     {
@@ -90,6 +93,7 @@ public class PathDescriptorTest
     }
 
     /** @throws Exception */
+    @Test
     public void testEmptyRelPath()
         throws Exception
     {
@@ -108,6 +112,7 @@ public class PathDescriptorTest
     }
 
     /** @throws Exception */
+    @Test
     public void testNullPath()
         throws Exception
     {
@@ -126,6 +131,7 @@ public class PathDescriptorTest
     }
 
     /** @throws Exception */
+    @Test
     public void testNullBaseAbsPath()
         throws Exception
     {
@@ -145,6 +151,7 @@ public class PathDescriptorTest
     }
 
     /** @throws Exception */
+    @Test
     public void testNullBaseRelPath()
         throws Exception
     {
@@ -164,6 +171,7 @@ public class PathDescriptorTest
     }
 
     /** @throws Exception */
+    @Test
     public void testNullBaseEmptyAbsPath()
         throws Exception
     {
@@ -183,6 +191,7 @@ public class PathDescriptorTest
     }
 
     /** @throws Exception */
+    @Test
     public void testNullBaseEmptyRelPath()
         throws Exception
     {
@@ -202,6 +211,7 @@ public class PathDescriptorTest
     }
 
     /** @throws Exception */
+    @Test
     public void testNullBaseNullPath()
         throws Exception
     {
@@ -221,6 +231,7 @@ public class PathDescriptorTest
     }
 
     /** @throws Exception */
+    @Test
     public void testUrlBaseAbsPath()
         throws Exception
     {
@@ -240,6 +251,7 @@ public class PathDescriptorTest
     }
 
     /** @throws Exception */
+    @Test
     public void testUrlBaseRelPath()
         throws Exception
     {
@@ -259,6 +271,7 @@ public class PathDescriptorTest
     }
 
     /** @throws Exception */
+    @Test
     public void testUrlBaseEmptyAbsPath()
         throws Exception
     {
@@ -278,6 +291,7 @@ public class PathDescriptorTest
     }
 
     /** @throws Exception */
+    @Test
     public void testUrlBaseEmptyRelPath()
         throws Exception
     {
@@ -297,6 +311,7 @@ public class PathDescriptorTest
     }
 
     /** @throws Exception */
+    @Test
     public void testUrlBaseNullPath()
         throws Exception
     {
@@ -316,6 +331,7 @@ public class PathDescriptorTest
     }
 
     /** @throws Exception */
+    @Test
     public void testFileBaseAbsPath()
         throws Exception
     {
@@ -344,6 +360,7 @@ public class PathDescriptorTest
     }
 
     /** @throws Exception */
+    @Test
     public void testFileBaseRelPath()
         throws Exception
     {
@@ -372,6 +389,7 @@ public class PathDescriptorTest
     }
 
     /** @throws Exception */
+    @Test
     public void testFileBaseEmptyAbsPath()
         throws Exception
     {
@@ -400,6 +418,7 @@ public class PathDescriptorTest
     }
 
     /** @throws Exception */
+    @Test
     public void testFileBaseEmptyRelPath()
         throws Exception
     {
@@ -428,6 +447,7 @@ public class PathDescriptorTest
     }
 
     /** @throws Exception */
+    @Test
     public void testFileBaseNullPath()
         throws Exception
     {
@@ -468,6 +488,7 @@ public class PathDescriptorTest
 */
 
     /** @throws Exception */
+    @Test
     public void testPathBaseAbsPath()
         throws Exception
     {
@@ -496,6 +517,7 @@ public class PathDescriptorTest
     }
 
     /** @throws Exception */
+    @Test
     public void testPathBaseRelPath()
         throws Exception
     {
@@ -524,6 +546,7 @@ public class PathDescriptorTest
     }
 
     /** @throws Exception */
+    @Test
     public void testPathBaseEmptyAbsPath()
         throws Exception
     {
@@ -552,6 +575,7 @@ public class PathDescriptorTest
     }
 
     /** @throws Exception */
+    @Test
     public void testPathBaseEmptyRelPath()
         throws Exception
     {
@@ -580,6 +604,7 @@ public class PathDescriptorTest
     }
 
     /** @throws Exception */
+    @Test
     public void testPathBaseNullPath()
         throws Exception
     {
@@ -608,6 +633,7 @@ public class PathDescriptorTest
     }
 
     /** @throws Exception */
+    @Test
     public void testPathRelBase()
         throws Exception
     {
